# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class RoleApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_assignees(self, id, **kwargs):  # noqa: E501
        """Add multiple users and user groups to a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_assignees(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of users and user groups thatshould be added to role
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_assignees_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_assignees_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def add_assignees_with_http_info(self, id, **kwargs):  # noqa: E501
        """Add multiple users and user groups to a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_assignees_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of users and user groups thatshould be added to role
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_assignees" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `add_assignees`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/role/{id}/addAssignees', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerRoleDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_role(self, **kwargs):  # noqa: E501
        """Create a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_role(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RoleDTO body: Example Body:  <pre>{   \"name\": \"Role name\",   \"permissions\": [   \"permission1\",   \"permission2\",   \"permission3\"   ],   \"description\": \"Role description\" }</pre>
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_role_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_role_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_role_with_http_info(self, **kwargs):  # noqa: E501
        """Create a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_role_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RoleDTO body: Example Body:  <pre>{   \"name\": \"Role name\",   \"permissions\": [   \"permission1\",   \"permission2\",   \"permission3\"   ],   \"description\": \"Role description\" }</pre>
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_role" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/role', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerRoleDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_role(self, id, **kwargs):  # noqa: E501
        """Delete a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_role(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_role_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_role_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_role_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_role_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/role/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerRoleDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_roles(self, **kwargs):  # noqa: E501
        """Get all roles for a customer  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_roles(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerPagedRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_roles_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_roles_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_roles_with_http_info(self, **kwargs):  # noqa: E501
        """Get all roles for a customer  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_roles_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerPagedRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_roles" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/role', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerPagedRoleDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_role(self, id, **kwargs):  # noqa: E501
        """Get a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_role(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_role_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_role_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_role_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_role_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/role/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerRoleDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def grant_permission_to_roles(self, permission, **kwargs):  # noqa: E501
        """Grants a single permission to role(s)  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.grant_permission_to_roles(permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str permission: Permission to grant to role(s). (required)
        :param list[str] body: List of roles.
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.grant_permission_to_roles_with_http_info(permission, **kwargs)  # noqa: E501
        else:
            (data) = self.grant_permission_to_roles_with_http_info(permission, **kwargs)  # noqa: E501
            return data

    def grant_permission_to_roles_with_http_info(self, permission, **kwargs):  # noqa: E501
        """Grants a single permission to role(s)  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.grant_permission_to_roles_with_http_info(permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str permission: Permission to grant to role(s). (required)
        :param list[str] body: List of roles.
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['permission', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method grant_permission_to_roles" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'permission' is set
        if self.api_client.client_side_validation and ('permission' not in params or
                                                       params['permission'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `permission` when calling `grant_permission_to_roles`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'permission' in params:
            path_params['permission'] = params['permission']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/role/grant/{permission}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerRoleDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_assignees(self, id, **kwargs):  # noqa: E501
        """Remove multiple users and user groups from a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_assignees(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of users and user groups thatshould be removed from role
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_assignees_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_assignees_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def remove_assignees_with_http_info(self, id, **kwargs):  # noqa: E501
        """Remove multiple users and user groups from a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_assignees_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of users and user groups thatshould be removed from role
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_assignees" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `remove_assignees`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/role/{id}/removeAssignees', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerRoleDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revoke_permission_from_roles(self, permission, **kwargs):  # noqa: E501
        """Revokes a single permission from role(s)  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revoke_permission_from_roles(permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str permission: Permission to revoke from role(s). (required)
        :param list[str] body: List of roles.
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revoke_permission_from_roles_with_http_info(permission, **kwargs)  # noqa: E501
        else:
            (data) = self.revoke_permission_from_roles_with_http_info(permission, **kwargs)  # noqa: E501
            return data

    def revoke_permission_from_roles_with_http_info(self, permission, **kwargs):  # noqa: E501
        """Revokes a single permission from role(s)  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revoke_permission_from_roles_with_http_info(permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str permission: Permission to revoke from role(s). (required)
        :param list[str] body: List of roles.
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['permission', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revoke_permission_from_roles" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'permission' is set
        if self.api_client.client_side_validation and ('permission' not in params or
                                                       params['permission'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `permission` when calling `revoke_permission_from_roles`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'permission' in params:
            path_params['permission'] = params['permission']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/role/revoke/{permission}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerRoleDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_role(self, id, **kwargs):  # noqa: E501
        """Update a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_role(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param RoleDTO body: Example Body:  <pre>{   \"id\": \"Role identifier\",   \"name\": \"Role name\",   \"permissions\": [   \"permission1\",   \"permission2\",   \"permission3\"   ],   \"description\": \"Role description\" }</pre>
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_role_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_role_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_role_with_http_info(self, id, **kwargs):  # noqa: E501
        """Update a specific role  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_role_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param RoleDTO body: Example Body:  <pre>{   \"id\": \"Role identifier\",   \"name\": \"Role name\",   \"permissions\": [   \"permission1\",   \"permission2\",   \"permission3\"   ],   \"description\": \"Role description\" }</pre>
        :return: ResponseContainerRoleDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/role/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerRoleDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Dashboard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'acl': 'AccessControlListSimple',
        'chart_title_bg_color': 'str',
        'chart_title_color': 'str',
        'chart_title_scalar': 'int',
        'created_epoch_millis': 'int',
        'creator_id': 'str',
        'customer': 'str',
        'dashboard_attributes': 'JsonNode',
        'default_end_time': 'int',
        'default_start_time': 'int',
        'default_time_window': 'str',
        'deleted': 'bool',
        'description': 'str',
        'display_description': 'bool',
        'display_query_parameters': 'bool',
        'display_section_table_of_contents': 'bool',
        'event_filter_type': 'str',
        'event_query': 'str',
        'favorite': 'bool',
        'force_v2_ui': 'bool',
        'hidden': 'bool',
        'id': 'str',
        'modify_acl_access': 'bool',
        'name': 'str',
        'num_charts': 'int',
        'num_favorites': 'int',
        'orphan': 'bool',
        'parameter_details': 'dict(str, DashboardParameterValue)',
        'parameters': 'dict(str, str)',
        'sections': 'list[DashboardSection]',
        'system_owned': 'bool',
        'tags': 'WFTags',
        'updated_epoch_millis': 'int',
        'updater_id': 'str',
        'url': 'str',
        'views_last_day': 'int',
        'views_last_month': 'int',
        'views_last_week': 'int'
    }

    attribute_map = {
        'acl': 'acl',
        'chart_title_bg_color': 'chartTitleBgColor',
        'chart_title_color': 'chartTitleColor',
        'chart_title_scalar': 'chartTitleScalar',
        'created_epoch_millis': 'createdEpochMillis',
        'creator_id': 'creatorId',
        'customer': 'customer',
        'dashboard_attributes': 'dashboardAttributes',
        'default_end_time': 'defaultEndTime',
        'default_start_time': 'defaultStartTime',
        'default_time_window': 'defaultTimeWindow',
        'deleted': 'deleted',
        'description': 'description',
        'display_description': 'displayDescription',
        'display_query_parameters': 'displayQueryParameters',
        'display_section_table_of_contents': 'displaySectionTableOfContents',
        'event_filter_type': 'eventFilterType',
        'event_query': 'eventQuery',
        'favorite': 'favorite',
        'force_v2_ui': 'forceV2UI',
        'hidden': 'hidden',
        'id': 'id',
        'modify_acl_access': 'modifyAclAccess',
        'name': 'name',
        'num_charts': 'numCharts',
        'num_favorites': 'numFavorites',
        'orphan': 'orphan',
        'parameter_details': 'parameterDetails',
        'parameters': 'parameters',
        'sections': 'sections',
        'system_owned': 'systemOwned',
        'tags': 'tags',
        'updated_epoch_millis': 'updatedEpochMillis',
        'updater_id': 'updaterId',
        'url': 'url',
        'views_last_day': 'viewsLastDay',
        'views_last_month': 'viewsLastMonth',
        'views_last_week': 'viewsLastWeek'
    }

    def __init__(self, acl=None, chart_title_bg_color=None, chart_title_color=None, chart_title_scalar=None, created_epoch_millis=None, creator_id=None, customer=None, dashboard_attributes=None, default_end_time=None, default_start_time=None, default_time_window=None, deleted=None, description=None, display_description=None, display_query_parameters=None, display_section_table_of_contents=None, event_filter_type=None, event_query=None, favorite=None, force_v2_ui=None, hidden=None, id=None, modify_acl_access=None, name=None, num_charts=None, num_favorites=None, orphan=None, parameter_details=None, parameters=None, sections=None, system_owned=None, tags=None, updated_epoch_millis=None, updater_id=None, url=None, views_last_day=None, views_last_month=None, views_last_week=None, _configuration=None):  # noqa: E501
        """Dashboard - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._acl = None
        self._chart_title_bg_color = None
        self._chart_title_color = None
        self._chart_title_scalar = None
        self._created_epoch_millis = None
        self._creator_id = None
        self._customer = None
        self._dashboard_attributes = None
        self._default_end_time = None
        self._default_start_time = None
        self._default_time_window = None
        self._deleted = None
        self._description = None
        self._display_description = None
        self._display_query_parameters = None
        self._display_section_table_of_contents = None
        self._event_filter_type = None
        self._event_query = None
        self._favorite = None
        self._force_v2_ui = None
        self._hidden = None
        self._id = None
        self._modify_acl_access = None
        self._name = None
        self._num_charts = None
        self._num_favorites = None
        self._orphan = None
        self._parameter_details = None
        self._parameters = None
        self._sections = None
        self._system_owned = None
        self._tags = None
        self._updated_epoch_millis = None
        self._updater_id = None
        self._url = None
        self._views_last_day = None
        self._views_last_month = None
        self._views_last_week = None
        self.discriminator = None

        if acl is not None:
            self.acl = acl
        if chart_title_bg_color is not None:
            self.chart_title_bg_color = chart_title_bg_color
        if chart_title_color is not None:
            self.chart_title_color = chart_title_color
        if chart_title_scalar is not None:
            self.chart_title_scalar = chart_title_scalar
        if created_epoch_millis is not None:
            self.created_epoch_millis = created_epoch_millis
        if creator_id is not None:
            self.creator_id = creator_id
        if customer is not None:
            self.customer = customer
        if dashboard_attributes is not None:
            self.dashboard_attributes = dashboard_attributes
        if default_end_time is not None:
            self.default_end_time = default_end_time
        if default_start_time is not None:
            self.default_start_time = default_start_time
        if default_time_window is not None:
            self.default_time_window = default_time_window
        if deleted is not None:
            self.deleted = deleted
        if description is not None:
            self.description = description
        if display_description is not None:
            self.display_description = display_description
        if display_query_parameters is not None:
            self.display_query_parameters = display_query_parameters
        if display_section_table_of_contents is not None:
            self.display_section_table_of_contents = display_section_table_of_contents
        if event_filter_type is not None:
            self.event_filter_type = event_filter_type
        if event_query is not None:
            self.event_query = event_query
        if favorite is not None:
            self.favorite = favorite
        if force_v2_ui is not None:
            self.force_v2_ui = force_v2_ui
        if hidden is not None:
            self.hidden = hidden
        self.id = id
        if modify_acl_access is not None:
            self.modify_acl_access = modify_acl_access
        self.name = name
        if num_charts is not None:
            self.num_charts = num_charts
        if num_favorites is not None:
            self.num_favorites = num_favorites
        if orphan is not None:
            self.orphan = orphan
        if parameter_details is not None:
            self.parameter_details = parameter_details
        if parameters is not None:
            self.parameters = parameters
        self.sections = sections
        if system_owned is not None:
            self.system_owned = system_owned
        if tags is not None:
            self.tags = tags
        if updated_epoch_millis is not None:
            self.updated_epoch_millis = updated_epoch_millis
        if updater_id is not None:
            self.updater_id = updater_id
        self.url = url
        if views_last_day is not None:
            self.views_last_day = views_last_day
        if views_last_month is not None:
            self.views_last_month = views_last_month
        if views_last_week is not None:
            self.views_last_week = views_last_week

    @property
    def acl(self):
        """Gets the acl of this Dashboard.  # noqa: E501


        :return: The acl of this Dashboard.  # noqa: E501
        :rtype: AccessControlListSimple
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """Sets the acl of this Dashboard.


        :param acl: The acl of this Dashboard.  # noqa: E501
        :type: AccessControlListSimple
        """

        self._acl = acl

    @property
    def chart_title_bg_color(self):
        """Gets the chart_title_bg_color of this Dashboard.  # noqa: E501

        Background color of the chart title text area, in rgba(rvalue,gvalue,bvalue,avalue)  # noqa: E501

        :return: The chart_title_bg_color of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._chart_title_bg_color

    @chart_title_bg_color.setter
    def chart_title_bg_color(self, chart_title_bg_color):
        """Sets the chart_title_bg_color of this Dashboard.

        Background color of the chart title text area, in rgba(rvalue,gvalue,bvalue,avalue)  # noqa: E501

        :param chart_title_bg_color: The chart_title_bg_color of this Dashboard.  # noqa: E501
        :type: str
        """

        self._chart_title_bg_color = chart_title_bg_color

    @property
    def chart_title_color(self):
        """Gets the chart_title_color of this Dashboard.  # noqa: E501

        Text color of the chart title text are, in rgba(rvalue,gvalue,bvalue,avalue)  # noqa: E501

        :return: The chart_title_color of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._chart_title_color

    @chart_title_color.setter
    def chart_title_color(self, chart_title_color):
        """Sets the chart_title_color of this Dashboard.

        Text color of the chart title text are, in rgba(rvalue,gvalue,bvalue,avalue)  # noqa: E501

        :param chart_title_color: The chart_title_color of this Dashboard.  # noqa: E501
        :type: str
        """

        self._chart_title_color = chart_title_color

    @property
    def chart_title_scalar(self):
        """Gets the chart_title_scalar of this Dashboard.  # noqa: E501

        Scale (normally 100) of chart title text size  # noqa: E501

        :return: The chart_title_scalar of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._chart_title_scalar

    @chart_title_scalar.setter
    def chart_title_scalar(self, chart_title_scalar):
        """Sets the chart_title_scalar of this Dashboard.

        Scale (normally 100) of chart title text size  # noqa: E501

        :param chart_title_scalar: The chart_title_scalar of this Dashboard.  # noqa: E501
        :type: int
        """

        self._chart_title_scalar = chart_title_scalar

    @property
    def created_epoch_millis(self):
        """Gets the created_epoch_millis of this Dashboard.  # noqa: E501


        :return: The created_epoch_millis of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._created_epoch_millis

    @created_epoch_millis.setter
    def created_epoch_millis(self, created_epoch_millis):
        """Sets the created_epoch_millis of this Dashboard.


        :param created_epoch_millis: The created_epoch_millis of this Dashboard.  # noqa: E501
        :type: int
        """

        self._created_epoch_millis = created_epoch_millis

    @property
    def creator_id(self):
        """Gets the creator_id of this Dashboard.  # noqa: E501


        :return: The creator_id of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this Dashboard.


        :param creator_id: The creator_id of this Dashboard.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def customer(self):
        """Gets the customer of this Dashboard.  # noqa: E501

        id of the customer to which this dashboard belongs  # noqa: E501

        :return: The customer of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this Dashboard.

        id of the customer to which this dashboard belongs  # noqa: E501

        :param customer: The customer of this Dashboard.  # noqa: E501
        :type: str
        """

        self._customer = customer

    @property
    def dashboard_attributes(self):
        """Gets the dashboard_attributes of this Dashboard.  # noqa: E501

        Experimental Dashboard Attributes  # noqa: E501

        :return: The dashboard_attributes of this Dashboard.  # noqa: E501
        :rtype: JsonNode
        """
        return self._dashboard_attributes

    @dashboard_attributes.setter
    def dashboard_attributes(self, dashboard_attributes):
        """Sets the dashboard_attributes of this Dashboard.

        Experimental Dashboard Attributes  # noqa: E501

        :param dashboard_attributes: The dashboard_attributes of this Dashboard.  # noqa: E501
        :type: JsonNode
        """

        self._dashboard_attributes = dashboard_attributes

    @property
    def default_end_time(self):
        """Gets the default_end_time of this Dashboard.  # noqa: E501

        Default end time in milliseconds to query charts  # noqa: E501

        :return: The default_end_time of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._default_end_time

    @default_end_time.setter
    def default_end_time(self, default_end_time):
        """Sets the default_end_time of this Dashboard.

        Default end time in milliseconds to query charts  # noqa: E501

        :param default_end_time: The default_end_time of this Dashboard.  # noqa: E501
        :type: int
        """

        self._default_end_time = default_end_time

    @property
    def default_start_time(self):
        """Gets the default_start_time of this Dashboard.  # noqa: E501

        Default start time in milliseconds to query charts  # noqa: E501

        :return: The default_start_time of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._default_start_time

    @default_start_time.setter
    def default_start_time(self, default_start_time):
        """Sets the default_start_time of this Dashboard.

        Default start time in milliseconds to query charts  # noqa: E501

        :param default_start_time: The default_start_time of this Dashboard.  # noqa: E501
        :type: int
        """

        self._default_start_time = default_start_time

    @property
    def default_time_window(self):
        """Gets the default_time_window of this Dashboard.  # noqa: E501

        Default time window to query charts  # noqa: E501

        :return: The default_time_window of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._default_time_window

    @default_time_window.setter
    def default_time_window(self, default_time_window):
        """Sets the default_time_window of this Dashboard.

        Default time window to query charts  # noqa: E501

        :param default_time_window: The default_time_window of this Dashboard.  # noqa: E501
        :type: str
        """

        self._default_time_window = default_time_window

    @property
    def deleted(self):
        """Gets the deleted of this Dashboard.  # noqa: E501


        :return: The deleted of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this Dashboard.


        :param deleted: The deleted of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def description(self):
        """Gets the description of this Dashboard.  # noqa: E501

        Human-readable description of the dashboard  # noqa: E501

        :return: The description of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Dashboard.

        Human-readable description of the dashboard  # noqa: E501

        :param description: The description of this Dashboard.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_description(self):
        """Gets the display_description of this Dashboard.  # noqa: E501

        Whether the dashboard description section is opened by default when the dashboard is shown  # noqa: E501

        :return: The display_description of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._display_description

    @display_description.setter
    def display_description(self, display_description):
        """Sets the display_description of this Dashboard.

        Whether the dashboard description section is opened by default when the dashboard is shown  # noqa: E501

        :param display_description: The display_description of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._display_description = display_description

    @property
    def display_query_parameters(self):
        """Gets the display_query_parameters of this Dashboard.  # noqa: E501

        Whether the dashboard parameters section is opened by default when the dashboard is shown  # noqa: E501

        :return: The display_query_parameters of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._display_query_parameters

    @display_query_parameters.setter
    def display_query_parameters(self, display_query_parameters):
        """Sets the display_query_parameters of this Dashboard.

        Whether the dashboard parameters section is opened by default when the dashboard is shown  # noqa: E501

        :param display_query_parameters: The display_query_parameters of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._display_query_parameters = display_query_parameters

    @property
    def display_section_table_of_contents(self):
        """Gets the display_section_table_of_contents of this Dashboard.  # noqa: E501

        Whether the \"pills\" quick-linked the sections of the dashboard are displayed by default when the dashboard is shown  # noqa: E501

        :return: The display_section_table_of_contents of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._display_section_table_of_contents

    @display_section_table_of_contents.setter
    def display_section_table_of_contents(self, display_section_table_of_contents):
        """Sets the display_section_table_of_contents of this Dashboard.

        Whether the \"pills\" quick-linked the sections of the dashboard are displayed by default when the dashboard is shown  # noqa: E501

        :param display_section_table_of_contents: The display_section_table_of_contents of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._display_section_table_of_contents = display_section_table_of_contents

    @property
    def event_filter_type(self):
        """Gets the event_filter_type of this Dashboard.  # noqa: E501

        How charts belonging to this dashboard should display events.  BYCHART is default if unspecified  # noqa: E501

        :return: The event_filter_type of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._event_filter_type

    @event_filter_type.setter
    def event_filter_type(self, event_filter_type):
        """Sets the event_filter_type of this Dashboard.

        How charts belonging to this dashboard should display events.  BYCHART is default if unspecified  # noqa: E501

        :param event_filter_type: The event_filter_type of this Dashboard.  # noqa: E501
        :type: str
        """
        allowed_values = ["BYCHART", "AUTOMATIC", "ALL", "NONE", "BYDASHBOARD", "BYCHARTANDDASHBOARD"]  # noqa: E501
        if (self._configuration.client_side_validation and
                event_filter_type not in allowed_values):
            raise ValueError(
                "Invalid value for `event_filter_type` ({0}), must be one of {1}"  # noqa: E501
                .format(event_filter_type, allowed_values)
            )

        self._event_filter_type = event_filter_type

    @property
    def event_query(self):
        """Gets the event_query of this Dashboard.  # noqa: E501

        Event query to run on dashboard charts  # noqa: E501

        :return: The event_query of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._event_query

    @event_query.setter
    def event_query(self, event_query):
        """Sets the event_query of this Dashboard.

        Event query to run on dashboard charts  # noqa: E501

        :param event_query: The event_query of this Dashboard.  # noqa: E501
        :type: str
        """

        self._event_query = event_query

    @property
    def favorite(self):
        """Gets the favorite of this Dashboard.  # noqa: E501


        :return: The favorite of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._favorite

    @favorite.setter
    def favorite(self, favorite):
        """Sets the favorite of this Dashboard.


        :param favorite: The favorite of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._favorite = favorite

    @property
    def force_v2_ui(self):
        """Gets the force_v2_ui of this Dashboard.  # noqa: E501

        Whether to force this dashboard to use the V2 UI  # noqa: E501

        :return: The force_v2_ui of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._force_v2_ui

    @force_v2_ui.setter
    def force_v2_ui(self, force_v2_ui):
        """Sets the force_v2_ui of this Dashboard.

        Whether to force this dashboard to use the V2 UI  # noqa: E501

        :param force_v2_ui: The force_v2_ui of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._force_v2_ui = force_v2_ui

    @property
    def hidden(self):
        """Gets the hidden of this Dashboard.  # noqa: E501


        :return: The hidden of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this Dashboard.


        :param hidden: The hidden of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    @property
    def id(self):
        """Gets the id of this Dashboard.  # noqa: E501

        Unique identifier, also URL slug, of the dashboard  # noqa: E501

        :return: The id of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Dashboard.

        Unique identifier, also URL slug, of the dashboard  # noqa: E501

        :param id: The id of this Dashboard.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def modify_acl_access(self):
        """Gets the modify_acl_access of this Dashboard.  # noqa: E501

        Whether the user has modify ACL access to the dashboard.  # noqa: E501

        :return: The modify_acl_access of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._modify_acl_access

    @modify_acl_access.setter
    def modify_acl_access(self, modify_acl_access):
        """Sets the modify_acl_access of this Dashboard.

        Whether the user has modify ACL access to the dashboard.  # noqa: E501

        :param modify_acl_access: The modify_acl_access of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._modify_acl_access = modify_acl_access

    @property
    def name(self):
        """Gets the name of this Dashboard.  # noqa: E501

        Name of the dashboard  # noqa: E501

        :return: The name of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Dashboard.

        Name of the dashboard  # noqa: E501

        :param name: The name of this Dashboard.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def num_charts(self):
        """Gets the num_charts of this Dashboard.  # noqa: E501


        :return: The num_charts of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._num_charts

    @num_charts.setter
    def num_charts(self, num_charts):
        """Sets the num_charts of this Dashboard.


        :param num_charts: The num_charts of this Dashboard.  # noqa: E501
        :type: int
        """

        self._num_charts = num_charts

    @property
    def num_favorites(self):
        """Gets the num_favorites of this Dashboard.  # noqa: E501


        :return: The num_favorites of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._num_favorites

    @num_favorites.setter
    def num_favorites(self, num_favorites):
        """Sets the num_favorites of this Dashboard.


        :param num_favorites: The num_favorites of this Dashboard.  # noqa: E501
        :type: int
        """

        self._num_favorites = num_favorites

    @property
    def orphan(self):
        """Gets the orphan of this Dashboard.  # noqa: E501


        :return: The orphan of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._orphan

    @orphan.setter
    def orphan(self, orphan):
        """Sets the orphan of this Dashboard.


        :param orphan: The orphan of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._orphan = orphan

    @property
    def parameter_details(self):
        """Gets the parameter_details of this Dashboard.  # noqa: E501

        The current (as of Wavefront 4.0) JSON representation of dashboard parameters.  This is a map from a parameter name to its representation  # noqa: E501

        :return: The parameter_details of this Dashboard.  # noqa: E501
        :rtype: dict(str, DashboardParameterValue)
        """
        return self._parameter_details

    @parameter_details.setter
    def parameter_details(self, parameter_details):
        """Sets the parameter_details of this Dashboard.

        The current (as of Wavefront 4.0) JSON representation of dashboard parameters.  This is a map from a parameter name to its representation  # noqa: E501

        :param parameter_details: The parameter_details of this Dashboard.  # noqa: E501
        :type: dict(str, DashboardParameterValue)
        """

        self._parameter_details = parameter_details

    @property
    def parameters(self):
        """Gets the parameters of this Dashboard.  # noqa: E501

        Deprecated.  An obsolete representation of dashboard parameters  # noqa: E501

        :return: The parameters of this Dashboard.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Dashboard.

        Deprecated.  An obsolete representation of dashboard parameters  # noqa: E501

        :param parameters: The parameters of this Dashboard.  # noqa: E501
        :type: dict(str, str)
        """

        self._parameters = parameters

    @property
    def sections(self):
        """Gets the sections of this Dashboard.  # noqa: E501

        Dashboard chart sections  # noqa: E501

        :return: The sections of this Dashboard.  # noqa: E501
        :rtype: list[DashboardSection]
        """
        return self._sections

    @sections.setter
    def sections(self, sections):
        """Sets the sections of this Dashboard.

        Dashboard chart sections  # noqa: E501

        :param sections: The sections of this Dashboard.  # noqa: E501
        :type: list[DashboardSection]
        """
        if self._configuration.client_side_validation and sections is None:
            raise ValueError("Invalid value for `sections`, must not be `None`")  # noqa: E501

        self._sections = sections

    @property
    def system_owned(self):
        """Gets the system_owned of this Dashboard.  # noqa: E501

        Whether this dashboard is system-owned and not writeable  # noqa: E501

        :return: The system_owned of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._system_owned

    @system_owned.setter
    def system_owned(self, system_owned):
        """Sets the system_owned of this Dashboard.

        Whether this dashboard is system-owned and not writeable  # noqa: E501

        :param system_owned: The system_owned of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._system_owned = system_owned

    @property
    def tags(self):
        """Gets the tags of this Dashboard.  # noqa: E501


        :return: The tags of this Dashboard.  # noqa: E501
        :rtype: WFTags
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Dashboard.


        :param tags: The tags of this Dashboard.  # noqa: E501
        :type: WFTags
        """

        self._tags = tags

    @property
    def updated_epoch_millis(self):
        """Gets the updated_epoch_millis of this Dashboard.  # noqa: E501


        :return: The updated_epoch_millis of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._updated_epoch_millis

    @updated_epoch_millis.setter
    def updated_epoch_millis(self, updated_epoch_millis):
        """Sets the updated_epoch_millis of this Dashboard.


        :param updated_epoch_millis: The updated_epoch_millis of this Dashboard.  # noqa: E501
        :type: int
        """

        self._updated_epoch_millis = updated_epoch_millis

    @property
    def updater_id(self):
        """Gets the updater_id of this Dashboard.  # noqa: E501


        :return: The updater_id of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._updater_id

    @updater_id.setter
    def updater_id(self, updater_id):
        """Sets the updater_id of this Dashboard.


        :param updater_id: The updater_id of this Dashboard.  # noqa: E501
        :type: str
        """

        self._updater_id = updater_id

    @property
    def url(self):
        """Gets the url of this Dashboard.  # noqa: E501

        Unique identifier, also URL slug, of the dashboard  # noqa: E501

        :return: The url of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Dashboard.

        Unique identifier, also URL slug, of the dashboard  # noqa: E501

        :param url: The url of this Dashboard.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and url is None:
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def views_last_day(self):
        """Gets the views_last_day of this Dashboard.  # noqa: E501


        :return: The views_last_day of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._views_last_day

    @views_last_day.setter
    def views_last_day(self, views_last_day):
        """Sets the views_last_day of this Dashboard.


        :param views_last_day: The views_last_day of this Dashboard.  # noqa: E501
        :type: int
        """

        self._views_last_day = views_last_day

    @property
    def views_last_month(self):
        """Gets the views_last_month of this Dashboard.  # noqa: E501


        :return: The views_last_month of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._views_last_month

    @views_last_month.setter
    def views_last_month(self, views_last_month):
        """Sets the views_last_month of this Dashboard.


        :param views_last_month: The views_last_month of this Dashboard.  # noqa: E501
        :type: int
        """

        self._views_last_month = views_last_month

    @property
    def views_last_week(self):
        """Gets the views_last_week of this Dashboard.  # noqa: E501


        :return: The views_last_week of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._views_last_week

    @views_last_week.setter
    def views_last_week(self, views_last_week):
        """Sets the views_last_week of this Dashboard.


        :param views_last_week: The views_last_week of this Dashboard.  # noqa: E501
        :type: int
        """

        self._views_last_week = views_last_week

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Dashboard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Dashboard):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Dashboard):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.ingestion_spy_api import IngestionSpyApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestIngestionSpyApi(unittest.TestCase):
    """IngestionSpyApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.ingestion_spy_api.IngestionSpyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_spy_on_delta_counters(self):
        """Test case for spy_on_delta_counters

        Gets new delta counters that are added to existing time series.  # noqa: E501
        """
        pass

    def test_spy_on_histograms(self):
        """Test case for spy_on_histograms

        Gets new histograms that are added to existing time series.  # noqa: E501
        """
        pass

    def test_spy_on_id_creations(self):
        """Test case for spy_on_id_creations

        Gets newly allocated IDs that correspond to new metric names, source names, point tags, or span tags. A new ID generally indicates that a new time series has been introduced.  # noqa: E501
        """
        pass

    def test_spy_on_points(self):
        """Test case for spy_on_points

        Gets a sampling of new metric data points that are added to existing time series.  # noqa: E501
        """
        pass

    def test_spy_on_spans(self):
        """Test case for spy_on_spans

        Gets new spans with existing source names and span tags.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class MonitoredApplicationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_all_applications(self, **kwargs):  # noqa: E501
        """Get all monitored services  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_applications(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerPagedMonitoredApplicationDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_applications_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_applications_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_applications_with_http_info(self, **kwargs):  # noqa: E501
        """Get all monitored services  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_applications_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerPagedMonitoredApplicationDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_applications" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/monitoredapplication', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerPagedMonitoredApplicationDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_application(self, application, **kwargs):  # noqa: E501
        """Get a specific application  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_application(application, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str application: (required)
        :return: ResponseContainerMonitoredApplicationDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_application_with_http_info(application, **kwargs)  # noqa: E501
        else:
            (data) = self.get_application_with_http_info(application, **kwargs)  # noqa: E501
            return data

    def get_application_with_http_info(self, application, **kwargs):  # noqa: E501
        """Get a specific application  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_application_with_http_info(application, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str application: (required)
        :return: ResponseContainerMonitoredApplicationDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['application']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_application" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'application' is set
        if self.api_client.client_side_validation and ('application' not in params or
                                                       params['application'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `application` when calling `get_application`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'application' in params:
            path_params['application'] = params['application']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/monitoredapplication/{application}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerMonitoredApplicationDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_service(self, application, **kwargs):  # noqa: E501
        """Update a specific service  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_service(application, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str application: (required)
        :param MonitoredApplicationDTO body: Example Body:  <pre>{   \"application\": \"beachshirts\",   \"satisfiedLatencyMillis\": \"100000\",   \"hidden\": \"false\" }</pre>
        :return: ResponseContainerMonitoredApplicationDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_service_with_http_info(application, **kwargs)  # noqa: E501
        else:
            (data) = self.update_service_with_http_info(application, **kwargs)  # noqa: E501
            return data

    def update_service_with_http_info(self, application, **kwargs):  # noqa: E501
        """Update a specific service  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_service_with_http_info(application, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str application: (required)
        :param MonitoredApplicationDTO body: Example Body:  <pre>{   \"application\": \"beachshirts\",   \"satisfiedLatencyMillis\": \"100000\",   \"hidden\": \"false\" }</pre>
        :return: ResponseContainerMonitoredApplicationDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['application', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_service" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'application' is set
        if self.api_client.client_side_validation and ('application' not in params or
                                                       params['application'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `application` when calling `update_service`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'application' in params:
            path_params['application'] = params['application']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/monitoredapplication/{application}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerMonitoredApplicationDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class CloudWatchConfiguration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'base_credentials': 'AWSBaseCredentials',
        'instance_selection_tags': 'dict(str, str)',
        'instance_selection_tags_expr': 'str',
        'metric_filter_regex': 'str',
        'namespaces': 'list[str]',
        'point_tag_filter_regex': 'str',
        'volume_selection_tags': 'dict(str, str)',
        'volume_selection_tags_expr': 'str'
    }

    attribute_map = {
        'base_credentials': 'baseCredentials',
        'instance_selection_tags': 'instanceSelectionTags',
        'instance_selection_tags_expr': 'instanceSelectionTagsExpr',
        'metric_filter_regex': 'metricFilterRegex',
        'namespaces': 'namespaces',
        'point_tag_filter_regex': 'pointTagFilterRegex',
        'volume_selection_tags': 'volumeSelectionTags',
        'volume_selection_tags_expr': 'volumeSelectionTagsExpr'
    }

    def __init__(self, base_credentials=None, instance_selection_tags=None, instance_selection_tags_expr=None, metric_filter_regex=None, namespaces=None, point_tag_filter_regex=None, volume_selection_tags=None, volume_selection_tags_expr=None, _configuration=None):  # noqa: E501
        """CloudWatchConfiguration - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._base_credentials = None
        self._instance_selection_tags = None
        self._instance_selection_tags_expr = None
        self._metric_filter_regex = None
        self._namespaces = None
        self._point_tag_filter_regex = None
        self._volume_selection_tags = None
        self._volume_selection_tags_expr = None
        self.discriminator = None

        if base_credentials is not None:
            self.base_credentials = base_credentials
        if instance_selection_tags is not None:
            self.instance_selection_tags = instance_selection_tags
        if instance_selection_tags_expr is not None:
            self.instance_selection_tags_expr = instance_selection_tags_expr
        if metric_filter_regex is not None:
            self.metric_filter_regex = metric_filter_regex
        if namespaces is not None:
            self.namespaces = namespaces
        if point_tag_filter_regex is not None:
            self.point_tag_filter_regex = point_tag_filter_regex
        if volume_selection_tags is not None:
            self.volume_selection_tags = volume_selection_tags
        if volume_selection_tags_expr is not None:
            self.volume_selection_tags_expr = volume_selection_tags_expr

    @property
    def base_credentials(self):
        """Gets the base_credentials of this CloudWatchConfiguration.  # noqa: E501


        :return: The base_credentials of this CloudWatchConfiguration.  # noqa: E501
        :rtype: AWSBaseCredentials
        """
        return self._base_credentials

    @base_credentials.setter
    def base_credentials(self, base_credentials):
        """Sets the base_credentials of this CloudWatchConfiguration.


        :param base_credentials: The base_credentials of this CloudWatchConfiguration.  # noqa: E501
        :type: AWSBaseCredentials
        """

        self._base_credentials = base_credentials

    @property
    def instance_selection_tags(self):
        """Gets the instance_selection_tags of this CloudWatchConfiguration.  # noqa: E501

        A string->string map of allow list of AWS instance tag-value pairs (in AWS).  If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.  Multiple entries are OR'ed  # noqa: E501

        :return: The instance_selection_tags of this CloudWatchConfiguration.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._instance_selection_tags

    @instance_selection_tags.setter
    def instance_selection_tags(self, instance_selection_tags):
        """Sets the instance_selection_tags of this CloudWatchConfiguration.

        A string->string map of allow list of AWS instance tag-value pairs (in AWS).  If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.  Multiple entries are OR'ed  # noqa: E501

        :param instance_selection_tags: The instance_selection_tags of this CloudWatchConfiguration.  # noqa: E501
        :type: dict(str, str)
        """

        self._instance_selection_tags = instance_selection_tags

    @property
    def instance_selection_tags_expr(self):
        """Gets the instance_selection_tags_expr of this CloudWatchConfiguration.  # noqa: E501

        A string expressing the allow list of AWS instance tag-value pairs.  If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.  Multiple entries are OR'ed and also OR'ed with entries from instanceSelectionTags.  Key-value pairs in the string are separated by commas and in the form k=v.  Example: \"k1=v1, k1=v2, k3=v3\".  # noqa: E501

        :return: The instance_selection_tags_expr of this CloudWatchConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._instance_selection_tags_expr

    @instance_selection_tags_expr.setter
    def instance_selection_tags_expr(self, instance_selection_tags_expr):
        """Sets the instance_selection_tags_expr of this CloudWatchConfiguration.

        A string expressing the allow list of AWS instance tag-value pairs.  If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.  Multiple entries are OR'ed and also OR'ed with entries from instanceSelectionTags.  Key-value pairs in the string are separated by commas and in the form k=v.  Example: \"k1=v1, k1=v2, k3=v3\".  # noqa: E501

        :param instance_selection_tags_expr: The instance_selection_tags_expr of this CloudWatchConfiguration.  # noqa: E501
        :type: str
        """

        self._instance_selection_tags_expr = instance_selection_tags_expr

    @property
    def metric_filter_regex(self):
        """Gets the metric_filter_regex of this CloudWatchConfiguration.  # noqa: E501

        A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested  # noqa: E501

        :return: The metric_filter_regex of this CloudWatchConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._metric_filter_regex

    @metric_filter_regex.setter
    def metric_filter_regex(self, metric_filter_regex):
        """Sets the metric_filter_regex of this CloudWatchConfiguration.

        A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested  # noqa: E501

        :param metric_filter_regex: The metric_filter_regex of this CloudWatchConfiguration.  # noqa: E501
        :type: str
        """

        self._metric_filter_regex = metric_filter_regex

    @property
    def namespaces(self):
        """Gets the namespaces of this CloudWatchConfiguration.  # noqa: E501

        A list of namespace that limit what we query from CloudWatch.  # noqa: E501

        :return: The namespaces of this CloudWatchConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._namespaces

    @namespaces.setter
    def namespaces(self, namespaces):
        """Sets the namespaces of this CloudWatchConfiguration.

        A list of namespace that limit what we query from CloudWatch.  # noqa: E501

        :param namespaces: The namespaces of this CloudWatchConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._namespaces = namespaces

    @property
    def point_tag_filter_regex(self):
        """Gets the point_tag_filter_regex of this CloudWatchConfiguration.  # noqa: E501

        A regular expression that AWS tag key name must match (case-insensitively) in order to be ingested  # noqa: E501

        :return: The point_tag_filter_regex of this CloudWatchConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._point_tag_filter_regex

    @point_tag_filter_regex.setter
    def point_tag_filter_regex(self, point_tag_filter_regex):
        """Sets the point_tag_filter_regex of this CloudWatchConfiguration.

        A regular expression that AWS tag key name must match (case-insensitively) in order to be ingested  # noqa: E501

        :param point_tag_filter_regex: The point_tag_filter_regex of this CloudWatchConfiguration.  # noqa: E501
        :type: str
        """

        self._point_tag_filter_regex = point_tag_filter_regex

    @property
    def volume_selection_tags(self):
        """Gets the volume_selection_tags of this CloudWatchConfiguration.  # noqa: E501

        A string->string map of allow list of AWS volume tag-value pairs (in AWS).  If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.  Multiple entries are OR'ed  # noqa: E501

        :return: The volume_selection_tags of this CloudWatchConfiguration.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._volume_selection_tags

    @volume_selection_tags.setter
    def volume_selection_tags(self, volume_selection_tags):
        """Sets the volume_selection_tags of this CloudWatchConfiguration.

        A string->string map of allow list of AWS volume tag-value pairs (in AWS).  If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.  Multiple entries are OR'ed  # noqa: E501

        :param volume_selection_tags: The volume_selection_tags of this CloudWatchConfiguration.  # noqa: E501
        :type: dict(str, str)
        """

        self._volume_selection_tags = volume_selection_tags

    @property
    def volume_selection_tags_expr(self):
        """Gets the volume_selection_tags_expr of this CloudWatchConfiguration.  # noqa: E501

        A string expressing the allow list of AWS volume tag-value pairs.  If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.  Multiple entries are OR'ed and also OR'ed with entries from volumeSelectionTags.  Key-value pairs in the string are separated by commas and in the form k=v.  Example: \"k1=v1, k1=v2, k3=v3\".  # noqa: E501

        :return: The volume_selection_tags_expr of this CloudWatchConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._volume_selection_tags_expr

    @volume_selection_tags_expr.setter
    def volume_selection_tags_expr(self, volume_selection_tags_expr):
        """Sets the volume_selection_tags_expr of this CloudWatchConfiguration.

        A string expressing the allow list of AWS volume tag-value pairs.  If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.  Multiple entries are OR'ed and also OR'ed with entries from volumeSelectionTags.  Key-value pairs in the string are separated by commas and in the form k=v.  Example: \"k1=v1, k1=v2, k3=v3\".  # noqa: E501

        :param volume_selection_tags_expr: The volume_selection_tags_expr of this CloudWatchConfiguration.  # noqa: E501
        :type: str
        """

        self._volume_selection_tags_expr = volume_selection_tags_expr

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudWatchConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudWatchConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CloudWatchConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Source(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_epoch_millis': 'int',
        'creator_id': 'str',
        'description': 'str',
        'hidden': 'bool',
        'id': 'str',
        'marked_new_epoch_millis': 'int',
        'source_name': 'str',
        'tags': 'dict(str, bool)',
        'updated_epoch_millis': 'int',
        'updater_id': 'str'
    }

    attribute_map = {
        'created_epoch_millis': 'createdEpochMillis',
        'creator_id': 'creatorId',
        'description': 'description',
        'hidden': 'hidden',
        'id': 'id',
        'marked_new_epoch_millis': 'markedNewEpochMillis',
        'source_name': 'sourceName',
        'tags': 'tags',
        'updated_epoch_millis': 'updatedEpochMillis',
        'updater_id': 'updaterId'
    }

    def __init__(self, created_epoch_millis=None, creator_id=None, description=None, hidden=None, id=None, marked_new_epoch_millis=None, source_name=None, tags=None, updated_epoch_millis=None, updater_id=None, _configuration=None):  # noqa: E501
        """Source - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._created_epoch_millis = None
        self._creator_id = None
        self._description = None
        self._hidden = None
        self._id = None
        self._marked_new_epoch_millis = None
        self._source_name = None
        self._tags = None
        self._updated_epoch_millis = None
        self._updater_id = None
        self.discriminator = None

        if created_epoch_millis is not None:
            self.created_epoch_millis = created_epoch_millis
        if creator_id is not None:
            self.creator_id = creator_id
        if description is not None:
            self.description = description
        if hidden is not None:
            self.hidden = hidden
        self.id = id
        if marked_new_epoch_millis is not None:
            self.marked_new_epoch_millis = marked_new_epoch_millis
        self.source_name = source_name
        if tags is not None:
            self.tags = tags
        if updated_epoch_millis is not None:
            self.updated_epoch_millis = updated_epoch_millis
        if updater_id is not None:
            self.updater_id = updater_id

    @property
    def created_epoch_millis(self):
        """Gets the created_epoch_millis of this Source.  # noqa: E501


        :return: The created_epoch_millis of this Source.  # noqa: E501
        :rtype: int
        """
        return self._created_epoch_millis

    @created_epoch_millis.setter
    def created_epoch_millis(self, created_epoch_millis):
        """Sets the created_epoch_millis of this Source.


        :param created_epoch_millis: The created_epoch_millis of this Source.  # noqa: E501
        :type: int
        """

        self._created_epoch_millis = created_epoch_millis

    @property
    def creator_id(self):
        """Gets the creator_id of this Source.  # noqa: E501


        :return: The creator_id of this Source.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this Source.


        :param creator_id: The creator_id of this Source.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def description(self):
        """Gets the description of this Source.  # noqa: E501

        Description of this source  # noqa: E501

        :return: The description of this Source.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Source.

        Description of this source  # noqa: E501

        :param description: The description of this Source.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def hidden(self):
        """Gets the hidden of this Source.  # noqa: E501

        A derived field denoting whether this source has been hidden (e.g. excluding it from query autocomplete among other things)  # noqa: E501

        :return: The hidden of this Source.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this Source.

        A derived field denoting whether this source has been hidden (e.g. excluding it from query autocomplete among other things)  # noqa: E501

        :param hidden: The hidden of this Source.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    @property
    def id(self):
        """Gets the id of this Source.  # noqa: E501

        id of this source, must be exactly equivalent to 'sourceName'  # noqa: E501

        :return: The id of this Source.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Source.

        id of this source, must be exactly equivalent to 'sourceName'  # noqa: E501

        :param id: The id of this Source.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def marked_new_epoch_millis(self):
        """Gets the marked_new_epoch_millis of this Source.  # noqa: E501

        Epoch Millis when this source was marked as ~status.new  # noqa: E501

        :return: The marked_new_epoch_millis of this Source.  # noqa: E501
        :rtype: int
        """
        return self._marked_new_epoch_millis

    @marked_new_epoch_millis.setter
    def marked_new_epoch_millis(self, marked_new_epoch_millis):
        """Sets the marked_new_epoch_millis of this Source.

        Epoch Millis when this source was marked as ~status.new  # noqa: E501

        :param marked_new_epoch_millis: The marked_new_epoch_millis of this Source.  # noqa: E501
        :type: int
        """

        self._marked_new_epoch_millis = marked_new_epoch_millis

    @property
    def source_name(self):
        """Gets the source_name of this Source.  # noqa: E501

        The name of the source, usually set by ingested telemetry  # noqa: E501

        :return: The source_name of this Source.  # noqa: E501
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """Sets the source_name of this Source.

        The name of the source, usually set by ingested telemetry  # noqa: E501

        :param source_name: The source_name of this Source.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and source_name is None:
            raise ValueError("Invalid value for `source_name`, must not be `None`")  # noqa: E501

        self._source_name = source_name

    @property
    def tags(self):
        """Gets the tags of this Source.  # noqa: E501

        A Map (String -> boolean) Representing the source tags associated with this source.  To create a tag, set it as a KEY in this map, with associated value equal to true  # noqa: E501

        :return: The tags of this Source.  # noqa: E501
        :rtype: dict(str, bool)
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Source.

        A Map (String -> boolean) Representing the source tags associated with this source.  To create a tag, set it as a KEY in this map, with associated value equal to true  # noqa: E501

        :param tags: The tags of this Source.  # noqa: E501
        :type: dict(str, bool)
        """

        self._tags = tags

    @property
    def updated_epoch_millis(self):
        """Gets the updated_epoch_millis of this Source.  # noqa: E501


        :return: The updated_epoch_millis of this Source.  # noqa: E501
        :rtype: int
        """
        return self._updated_epoch_millis

    @updated_epoch_millis.setter
    def updated_epoch_millis(self, updated_epoch_millis):
        """Sets the updated_epoch_millis of this Source.


        :param updated_epoch_millis: The updated_epoch_millis of this Source.  # noqa: E501
        :type: int
        """

        self._updated_epoch_millis = updated_epoch_millis

    @property
    def updater_id(self):
        """Gets the updater_id of this Source.  # noqa: E501


        :return: The updater_id of this Source.  # noqa: E501
        :rtype: str
        """
        return self._updater_id

    @updater_id.setter
    def updater_id(self, updater_id):
        """Sets the updater_id of this Source.


        :param updater_id: The updater_id of this Source.  # noqa: E501
        :type: str
        """

        self._updater_id = updater_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Source, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Source):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Source):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class UserGroupApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_roles_to_user_group(self, id, **kwargs):  # noqa: E501
        """Add multiple roles to a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_roles_to_user_group(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of roles that should be added to user group
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_roles_to_user_group_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_roles_to_user_group_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def add_roles_to_user_group_with_http_info(self, id, **kwargs):  # noqa: E501
        """Add multiple roles to a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_roles_to_user_group_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of roles that should be added to user group
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_roles_to_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `add_roles_to_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usergroup/{id}/addRoles', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerUserGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_users_to_user_group(self, id, **kwargs):  # noqa: E501
        """Add multiple users to a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_users_to_user_group(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of users that should be added to user group
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_users_to_user_group_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_users_to_user_group_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def add_users_to_user_group_with_http_info(self, id, **kwargs):  # noqa: E501
        """Add multiple users to a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_users_to_user_group_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of users that should be added to user group
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_users_to_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `add_users_to_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usergroup/{id}/addUsers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerUserGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_user_group(self, **kwargs):  # noqa: E501
        """Create a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_group(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserGroupWrite body: Example Body:  <pre>{   \"name\": \"UserGroup name\",   \"permissions\": [   \"permission1\",   \"permission2\",   \"permission3\"   ],   \"roleIDs\": [   \"role1\",   \"role2\",   \"role3\"   ],   \"description\": \"UserGroup description\" }</pre>
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_user_group_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_user_group_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_user_group_with_http_info(self, **kwargs):  # noqa: E501
        """Create a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_group_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserGroupWrite body: Example Body:  <pre>{   \"name\": \"UserGroup name\",   \"permissions\": [   \"permission1\",   \"permission2\",   \"permission3\"   ],   \"roleIDs\": [   \"role1\",   \"role2\",   \"role3\"   ],   \"description\": \"UserGroup description\" }</pre>
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_user_group" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usergroup', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerUserGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_user_group(self, id, **kwargs):  # noqa: E501
        """Delete a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_group(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_user_group_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_user_group_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_user_group_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_group_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usergroup/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerUserGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_user_groups(self, **kwargs):  # noqa: E501
        """Get all user groups for a customer  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_user_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerPagedUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_user_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_user_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_user_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Get all user groups for a customer  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_user_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerPagedUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_user_groups" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usergroup', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerPagedUserGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_group(self, id, **kwargs):  # noqa: E501
        """Get a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_group(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_group_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_group_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_user_group_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_group_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usergroup/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerUserGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_roles_from_user_group(self, id, **kwargs):  # noqa: E501
        """Remove multiple roles from a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_roles_from_user_group(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of roles that should be removed from user group
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_roles_from_user_group_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_roles_from_user_group_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def remove_roles_from_user_group_with_http_info(self, id, **kwargs):  # noqa: E501
        """Remove multiple roles from a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_roles_from_user_group_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of roles that should be removed from user group
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_roles_from_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `remove_roles_from_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usergroup/{id}/removeRoles', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerUserGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_users_from_user_group(self, id, **kwargs):  # noqa: E501
        """Remove multiple users from a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_users_from_user_group(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of users that should be removed from user group
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_users_from_user_group_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_users_from_user_group_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def remove_users_from_user_group_with_http_info(self, id, **kwargs):  # noqa: E501
        """Remove multiple users from a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_users_from_user_group_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: List of users that should be removed from user group
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_users_from_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `remove_users_from_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usergroup/{id}/removeUsers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerUserGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_user_group(self, id, **kwargs):  # noqa: E501
        """Update a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_group(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UserGroupWrite body: Example Body:  <pre>{   \"id\": \"UserGroup identifier\",   \"name\": \"UserGroup name\",   \"permissions\": [   \"permission1\",   \"permission2\",   \"permission3\"   ],   \"roleIDs\": [   \"role1\",   \"role2\",   \"role3\"   ],   \"description\": \"UserGroup description\" }</pre>
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_user_group_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_user_group_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_user_group_with_http_info(self, id, **kwargs):  # noqa: E501
        """Update a specific user group  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_group_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UserGroupWrite body: Example Body:  <pre>{   \"id\": \"UserGroup identifier\",   \"name\": \"UserGroup name\",   \"permissions\": [   \"permission1\",   \"permission2\",   \"permission3\"   ],   \"roleIDs\": [   \"role1\",   \"role2\",   \"role3\"   ],   \"description\": \"UserGroup description\" }</pre>
        :return: ResponseContainerUserGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usergroup/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerUserGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class RawTimeseries(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'points': 'list[Point]',
        'tags': 'dict(str, str)'
    }

    attribute_map = {
        'points': 'points',
        'tags': 'tags'
    }

    def __init__(self, points=None, tags=None, _configuration=None):  # noqa: E501
        """RawTimeseries - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._points = None
        self._tags = None
        self.discriminator = None

        self.points = points
        if tags is not None:
            self.tags = tags

    @property
    def points(self):
        """Gets the points of this RawTimeseries.  # noqa: E501


        :return: The points of this RawTimeseries.  # noqa: E501
        :rtype: list[Point]
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this RawTimeseries.


        :param points: The points of this RawTimeseries.  # noqa: E501
        :type: list[Point]
        """
        if self._configuration.client_side_validation and points is None:
            raise ValueError("Invalid value for `points`, must not be `None`")  # noqa: E501

        self._points = points

    @property
    def tags(self):
        """Gets the tags of this RawTimeseries.  # noqa: E501

        Associated tags of the time series  # noqa: E501

        :return: The tags of this RawTimeseries.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this RawTimeseries.

        Associated tags of the time series  # noqa: E501

        :param tags: The tags of this RawTimeseries.  # noqa: E501
        :type: dict(str, str)
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RawTimeseries, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RawTimeseries):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RawTimeseries):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class AlertRoute(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filter': 'str',
        'method': 'str',
        'target': 'str'
    }

    attribute_map = {
        'filter': 'filter',
        'method': 'method',
        'target': 'target'
    }

    def __init__(self, filter=None, method=None, target=None, _configuration=None):  # noqa: E501
        """AlertRoute - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._filter = None
        self._method = None
        self._target = None
        self.discriminator = None

        self.filter = filter
        self.method = method
        self.target = target

    @property
    def filter(self):
        """Gets the filter of this AlertRoute.  # noqa: E501

        String that filters the route. Space delimited. Currently only allows single key value pair.  filter: env* prod*  # noqa: E501

        :return: The filter of this AlertRoute.  # noqa: E501
        :rtype: str
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """Sets the filter of this AlertRoute.

        String that filters the route. Space delimited. Currently only allows single key value pair.  filter: env* prod*  # noqa: E501

        :param filter: The filter of this AlertRoute.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and filter is None:
            raise ValueError("Invalid value for `filter`, must not be `None`")  # noqa: E501

        self._filter = filter

    @property
    def method(self):
        """Gets the method of this AlertRoute.  # noqa: E501

        The end point for the alert route.EMAIL: email address.  PAGERDUTY: PagerDuty routing Key.  WEBHOOK: URL end point  # noqa: E501

        :return: The method of this AlertRoute.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this AlertRoute.

        The end point for the alert route.EMAIL: email address.  PAGERDUTY: PagerDuty routing Key.  WEBHOOK: URL end point  # noqa: E501

        :param method: The method of this AlertRoute.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and method is None:
            raise ValueError("Invalid value for `method`, must not be `None`")  # noqa: E501
        allowed_values = ["WEBHOOK", "PAGERDUTY", "EMAIL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                method not in allowed_values):
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def target(self):
        """Gets the target of this AlertRoute.  # noqa: E501

        The end point for the notification target.EMAIL: email address.  PAGERDUTY: PagerDuty routing Key.  WEBHOOK: URL end point  # noqa: E501

        :return: The target of this AlertRoute.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this AlertRoute.

        The end point for the notification target.EMAIL: email address.  PAGERDUTY: PagerDuty routing Key.  WEBHOOK: URL end point  # noqa: E501

        :param target: The target of this AlertRoute.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and target is None:
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501

        self._target = target

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AlertRoute, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlertRoute):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AlertRoute):
            return True

        return self.to_dict() != other.to_dict()
